summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/location_bar_view.h
diff options
context:
space:
mode:
authorpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-30 10:02:16 +0000
committerpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-30 10:02:16 +0000
commitceb98432ad0891542fb213193dd8312aed41e3c6 (patch)
tree9372263ed8c7e045ad7226f44f28079a75661a46 /chrome/browser/views/location_bar_view.h
parentf85f070f8fca83ca373929584218d7185ff89220 (diff)
downloadchromium_src-ceb98432ad0891542fb213193dd8312aed41e3c6.zip
chromium_src-ceb98432ad0891542fb213193dd8312aed41e3c6.tar.gz
chromium_src-ceb98432ad0891542fb213193dd8312aed41e3c6.tar.bz2
Hook up some of the content settings UI to the actual settings map object. This also rewrites the affected UI bits to make it easier to do this, get rid of unnecessary code, and be more consistent with the blocked content bubble code.
BUG=32719 TEST=Content settings windows now have radio buttons that work, and remember their settings. The Flash link works too. Review URL: http://codereview.chromium.org/558060 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@37631 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/views/location_bar_view.h')
-rw-r--r--chrome/browser/views/location_bar_view.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/views/location_bar_view.h b/chrome/browser/views/location_bar_view.h
index fedee9d..4b405c3 100644
--- a/chrome/browser/views/location_bar_view.h
+++ b/chrome/browser/views/location_bar_view.h
@@ -102,9 +102,9 @@ class LocationBarView : public LocationBar,
void SetProfile(Profile* profile);
Profile* profile() { return profile_; }
- // Returns the display-formatted hostname for the current page. This should
- // only be used by the ContentBlockedImageView.
- std::wstring GetHost() const;
+ // Returns the URL for the current page. This should only be used by the
+ // ContentBlockedImageView.
+ GURL GetURL() const;
// Sets |preview_enabled| for the PageAction View associated with this
// |page_action|. If |preview_enabled| is true, the view will display the